@@ -1,13 +1,14 @@
-# encoding: utf-8
+# -*- coding:utf-8 -*-
+
 import logging
 from rest_framework.routers import SimpleRouter
-from .serializers import OrquestraSerializer
-from .api import OrquestraAPI, exception_translation
+from .serializers import DjangoServiceSerializer
+from .api import DjangoServiceAPI, exception_translation
 
 router = SimpleRouter()
 LOG = logging.getLogger(__name__)
 
-__all__ = ['OrquestraSerializer', 'OrquestraAPI', 'exception_translation', 'register']
+__all__ = ['DjangoServiceSerializer', 'DjangoServiceAPI', 'exception_translation', 'register']
 
 
 def register(name, viewsets, *args):
