@@ -1,4 +1,5 @@
-# encoding: utf-8
+# -*- coding:utf-8 -*-
+
 from django.shortcuts import render
 from django.core.urlresolvers import reverse
 from ..api import router
@@ -22,6 +23,7 @@ def api_help(request):
     return render(request, 'api_help.html', {
         "breadcrumblist": breadcrumblist,
         "api_doc_list": api_doc_list,
+        "request": request,
     }, content_type="text/html")
 
 
